/*
  CSS RESET
*/

html, body, div, span, applet, object, iframe, h1, h2, h3, h4, h5, h6, p, blockquote, pre, a, abbr, acronym, address, big, cite, code, del, dfn, em, img, ins, kbd, q, s, samp, small, strike, strong, sub, sup, tt, var, b, u, i, center, dl, dt, dd, ol, ul, li, fieldset, form, label, legend, table, caption, tbody, tfoot, thead, tr, th, td, article, aside, canvas, details, embed, figure, figcaption, footer, header, hgroup, menu, nav, output, ruby, section, summary, time, mark, audio, video {
    margin: 0;
    padding: 0;
    border: 0;
    font-size: 100%;
    font: inherit;
    vertical-align: baseline;
}
/* HTML5 display-role reset for older browsers */
article, aside, details, figcaption, figure, footer, header, hgroup, menu, nav, section {
    display: block;
}
body {
    line-height: 1;
}
ol, ul {
    list-style: none;
}
blockquote, q {
    quotes: none;
}
blockquote:before, blockquote:after,
q:before, q:after {
    content: '';
    content: none;
}
table {
    border-collapse: collapse;
    border-spacing: 0;
}

/*
  END CSS RESET
*/
html, body {
    font-family: sans-serif;
}

h1.title {
    text-align: center;
    font-size: 48px;
    margin: 20px 0px 20px 0px;
}

.box {
    border: 1px solid #aaa;
    width: 400px;
    height: 400px;
    margin-left: auto;
    margin-right: auto;
}

.box img {
    display: block;
    width: 200px;
    margin-top: 20px;
    margin-left: auto;
    margin-right: auto;
}

.top {
    height: 250px;
    width: 350px;
    padding-left: 50px;
    border: 0px solid;
    border-bottom: 1px solid #aaa;
}

.button {
    height: 25px;
    width: 100px;
    margin: 24px 24px 0px 24px;
    padding-top: 10px;
    text-align: center;
    border-radius: 10px;
    border: 1px solid;
}

.float {
    float: left;
}

.new-kitten {
    width: 150px;
    margin-left: auto;
    margin-right: auto;
}

.votes {
    width: 300px;
    margin-left: auto;
    margin-right: auto;
}